<template>
  <el-dialog title="项目选择"
             v-if="showFlag"
             :visible.sync="showFlag"
             :modal= false
             width="80%"
             center
  >
    <el-row :gutter="20">
      <!--设备数据-->
      <el-col :span="20" :xs="24">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
          <el-form-item label="设备编码" prop="machineryCode">
            <el-input
              v-model="queryParams.equipmentCode"
              placeholder="请输入设备编码"
              clearable
              style="width: 240px"
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item label="设备名称" prop="machineryName">
            <el-input
              v-model="queryParams.equipmentName"
              placeholder="请输入设备名称"
              clearable
              style="width: 240px"
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
          <el-form-item>
            <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
            <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
          </el-form-item>
        </el-form>
        <el-table v-loading="loading" :data="dvsubjectList" @selection-change="handleSelectionChange">
          <el-table-column type="selection" width="55" align="center" />
          <el-table-column label="项目名称" align="center" prop="itemsName">
          </el-table-column>
          <el-table-column label="项目编号" align="center" prop="itemsCode">
          </el-table-column>
          <el-table-column label="项目类型" align="center" prop="itemsType">
            <template slot-scope="scope">
              <dict-tag :options="dict.type.spotmaintenance" :value="scope.row.itemsType"/>
            </template>
          </el-table-column>
          <el-table-column label="项目内容" align="center" prop="itemsContent">
          </el-table-column>
          <el-table-column label="标准" align="center" prop="standard">
          </el-table-column>
          <el-table-column label="创建人" align="center" prop="createUser">
          </el-table-column>
          <el-table-column label="创建时间" align="center" prop="createTime">
          </el-table-column>
          <el-table-column label="更新人" align="center" prop="updateUser">
          </el-table-column>
          <el-table-column label="更新时间" align="center" prop="updateTime">
          </el-table-column>
        </el-table>

        <pagination
          v-show="total>0"
          :total="total"
          :page.sync="queryParams.pageNum"
          :limit.sync="queryParams.pageSize"
          @pagination="getList"
        />
      </el-col>
    </el-row>
    <div slot="footer" class="dialog-footer">
      <el-button type="primary" @click="confirmSelect">确 定</el-button>
      <el-button @click="showFlag=false">取 消</el-button>
    </div>
  </el-dialog>
</template>

<script>

import { listInspectionItems, getInspectionItems, delInspectionItems, addInspectionItems, updateInspectionItems } from "@/api/main/em/inspectionItems/inspectionItems";


export default {
  name: "DvsubjectSelect",
  dicts: ['sys_yes_no','mes_machinery_status','spotmaintenance'],
  components: {  },
  data() {
    return {
      showFlag:false,
      // 遮罩层
      loading: true,
      // 选中数组s
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 设备点检保养项目表格数据
      dvsubjectList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        itemsCode: null,
        itemsName: null,
        itemsType: null,
        standard: null,
        itemsContent: null,
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询点检项目列表 */
    getList() {
      this.loading = true;
      listInspectionItems(this.queryParams).then(response => {
          this.dvsubjectList = response.rows;
          this.total = response.total;
          this.loading = false;

        },
      );
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.machineryId);
      this.selectedRows = selection;
      this.single = selection.length != 1;
      this.multiple = !selection.length;
    },
    //确定选中
    confirmSelect(){
      if(this.ids ==[] || this.ids.length==0){
        this.$notify({
          title:'提示',
          type:'warning',
          message: '请至少选择一条数据!'
        });
        return;
      }
      this.$emit('onSelected',this.selectedRows);
      this.showFlag = false;
    }
  }
};
</script>
